@@ -1,8 +1,8 @@
-# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Client.pm,v 1.17 2008/01/23 12:23:16 gavin Exp $
+# $Id: Client.pm,v 1.17 2011/01/23 12:23:16 gavin Exp $
 package Net::EPP::Client;
 use bytes;
 use Net::EPP::Protocol;
@@ -10,7 +10,6 @@ use Carp;
 use IO::Socket;
 use IO::Socket::SSL;
 use vars qw($XMLDOM $EPPFRAME);
-use UNIVERSAL qw(isa);
 use strict;
 use warnings;
 
@@ -185,7 +184,7 @@ certificate information). See the relevant manpage for examples.
 This method will C<croak()> if connection fails, so be sure to use C<eval()> if
 you want to catch the error.
 
-The return value for C<connect()> will be the EPP C<E<lt>greetingE<gt>> frame
+The return value for C<connect()> will be the EPP E<lt>greetingE<gt> frame
 returned by the server. Please note that the same caveat about blocking applies
 to this method as to C<get_frame()> (see below).
 
@@ -237,7 +236,7 @@ sub _connect_unix {
 		%params
 	);
 
-	croak("Connection to $self->{'host'}:$self->{'port'} failed: \"$@\"") if (!defined($self->{'connection'}) || ($@ && $@ ne ''));
+	croak("Connection to $self->{'host'}:$self->{'port'} failed: $@") if (!defined($self->{'connection'}) || ($@ && $@ ne ''));
 
 	return 1;
 
@@ -390,7 +389,7 @@ sub send_frame {
 	$epp->disconnect;
 
 This closes the connection. An EPP server should always close a connection after
-a C<E<lt>logoutE<gt>> frame has been received and acknowledged; this method
+a E<lt>logoutE<gt> frame has been received and acknowledged; this method
 is provided to allow you to clean up on the client side, or close the
 connection out of sync with the server.
 
@@ -410,7 +409,7 @@ CentralNic Ltd (L<http://www.centralnic.com/>).
 
 =head1 COPYRIGHT
 
-This module is (c) 2006 CentralNic Ltd. This module is free software; you can
+This module is (c) 2011 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
