@@ -1,4 +1,4 @@
-# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
@@ -20,7 +20,7 @@ for domain objects.
 	use Net::EPP::Frame::Command::Create::Domain;
 	use strict;
 
-	my $check = Net::EPP::Frame::Command::Create::Domain->new;
+	my $create = Net::EPP::Frame::Command::Create::Domain->new;
 	$create->setDomain('example.uk.com);
 
 	print $create->toString(1);
@@ -29,7 +29,7 @@ This results in an XML document like this:
 
 	<?xml version="1.0" encoding="UTF-8"?>
 	<epp xmlns="urn:ietf:params:xml:ns:epp-1.0"
-	  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+	  xmlns:xsi="http://www.w3.org/2011/XMLSchema-instance"
 	  xsi:schemaLocation="urn:ietf:params:xml:ns:epp-1.0
 	  epp-1.0.xsd">
 	    <command>
@@ -202,7 +202,7 @@ sub addHostObjNS {
 sub setAuthInfo {
 	my ($self, $authInfo) = @_;
 	my $el = $self->addEl('authInfo');
-	my $pw = $self->createElement('pw');
+	my $pw = $self->createElement('domain:pw');
 	$pw->appendText($authInfo);
 	$el->appendChild($pw);
 	return $el;
@@ -233,7 +233,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2007 CentralNic Ltd. This module is free software; you can
+This module is (c) 2011 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
