@@ -1,8 +1,8 @@
-# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Contact.pm,v 1.3 2008/01/23 12:26:24 gavin Exp $
+# $Id: Contact.pm,v 1.3 2011/01/23 12:26:24 gavin Exp $
 package Net::EPP::Frame::Command::Delete::Contact;
 use base qw(Net::EPP::Frame::Command::Delete);
 use Net::EPP::Frame::ObjectSpec;
@@ -21,7 +21,7 @@ for contact objects.
 	use strict;
 
 	my $delete = Net::EPP::Frame::Command::Delete::Contact->new;
-	$delete->setHost('example.tld');
+	$delete->setContact('contact-id');
 
 	print $delete->toString(1);
 
@@ -29,7 +29,7 @@ This results in an XML document like this:
 
 	<?xml version="1.0" encoding="UTF-8"?>
 	<epp xmlns="urn:ietf:params:xml:ns:epp-1.0"
-	  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+	  xmlns:xsi="http://www.w3.org/2011/XMLSchema-instance"
 	  xsi:schemaLocation="urn:ietf:params:xml:ns:epp-1.0
 	  epp-1.0.xsd">
 	    <command>
@@ -38,7 +38,7 @@ This results in an XML document like this:
 	          xmlns:contact="urn:ietf:params:xml:ns:contact-1.0"
 	          xsi:schemaLocation="urn:ietf:params:xml:ns:contact-1.0
 	          contact-1.0.xsd">
-	            <contact:name>ns0.example.tldE<lt>/contact:name>
+	            <contact:name>contact-idE<lt>/contact:name>
 	        </contact:delete>
 	      </delete>
 	      <clTRID>0cf1b8f7e14547d26f03b7641660c641d9e79f45</clTRIDE<gt>
@@ -94,7 +94,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2007 CentralNic Ltd. This module is free software; you can
+This module is (c) 2011 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
