@@ -1,8 +1,8 @@
-# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Contact.pm,v 1.3 2007/12/03 11:44:52 gavin Exp $
+# $Id: Contact.pm,v 1.3 2011/12/03 11:44:52 gavin Exp $
 package Net::EPP::Frame::Command::Update::Contact;
 use base qw(Net::EPP::Frame::Command::Update);
 use Net::EPP::Frame::ObjectSpec;
@@ -21,7 +21,7 @@ for contact objects.
 	use strict;
 
 	my $info = Net::EPP::Frame::Command::Update::Contact->new;
-	$info->setID('REG-12345');
+	$info->setContact('REG-12345');
 
 	print $info->toString(1);
 
@@ -29,7 +29,7 @@ This results in an XML document like this:
 
 	<?xml version="1.0" encoding="UTF-8"?>
 	<epp xmlns="urn:ietf:params:xml:ns:epp-1.0"
-	  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+	  xmlns:xsi="http://www.w3.org/2011/XMLSchema-instance"
 	  xsi:schemaLocation="urn:ietf:params:xml:ns:epp-1.0
 	  epp-1.0.xsd">
 	    <command>
@@ -86,7 +86,8 @@ sub setContact {
 	my $el = $self->createElement('contact:id');
 	$el->appendText($id);
 
-	$self->getNode('update')->getChildNodes->shift->appendChild($el);
+	my $n = $self->getNode('update')->getChildNodes->shift;
+	$n->insertBefore( $el, $n->firstChild );
 
 	return 1;
 }
@@ -99,7 +100,7 @@ CentralNic Ltd (http://www.centralnic.com/).
 
 =head1 COPYRIGHT
 
-This module is (c) 2007 CentralNic Ltd. This module is free software; you can
+This module is (c) 2011 CentralNic Ltd. This module is free software; you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
